TTSDKConfiguration class

Constructors

TTSDKConfiguration.defaultConfigurationWithAppIDAndLicPath({required String appID, required String licenseFilePath, required String channel})

Properties

appID ↔ String
getter/setter pair
appName ↔ String?
getter/setter pair
appRegion ↔ TTSDKServiceVendor?
getter/setter pair
appVersion ↔ String?
getter/setter pair
channel ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
licenseFilePath ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vodConfiguration ↔ TTSDKVodConfiguration?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited