VideoModelImpl class

Video model implementation class

Implemented types

Constructors

VideoModelImpl({String? vid, int? duration, List<TTVideoEngineResolutionType>? supportedResolutions})
VideoModelImpl.fromMap(Map<String, dynamic> map)
Create VideoModel from Map
factory

Properties

duration → int?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedResolutions → List<TTVideoEngineResolutionType>?
final
vid → String?
final

Methods

getDuration() → int?
Get video duration (in milliseconds)
override
getSupportedResolutions() → List<TTVideoEngineResolutionType>?
Get video title Get list of supported resolutions
override
getVid() → String?
Get video ID
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert to Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited