TTVideoEngineDownloadTask class abstract

Implementers

Constructors

TTVideoEngineDownloadTask()

Properties

availableLocalFilePath → String?
no setter
countOfBytesExpectedToReceive → int?
no setter
countOfBytesReceived → int?
no setter
error → TTError?
no setter
hashCode → int
The hash code for this object.
no setterinherited
progress → double?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TTVideoEngineDownloadState?
no setter
taskId → String?
no setter

Methods

invalidateAndCancel() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resume() → void
suspend() → void
toJson() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map json) → TTVideoEngineDownloadTask