TTVideoEngineDownloadURLTask class

Inheritance

Constructors

TTVideoEngineDownloadURLTask({List<String>? urls, String? cacheKey, String? videoId, int? countOfBytesReceived, int? countOfBytesExpectedToReceive, double? progress, TTVideoEngineDownloadState? state, TTError? error, String? availableLocalFilePath, String? taskId})
TTVideoEngineDownloadURLTask.fromJson(Map json)
factory

Properties

availableLocalFilePath → String?
final
cacheKey ↔ String?
getter/setter pair
countOfBytesExpectedToReceive → int?
final
countOfBytesReceived → int?
final
error → TTError?
final
hashCode → int
The hash code for this object.
no setterinherited
progress → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TTVideoEngineDownloadState?
final
taskId → String?
final
urls ↔ List<String>?
getter/setter pair
videoId ↔ String?
getter/setter pair

Methods

invalidateAndCancel() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resume() → void
override
suspend() → void
override
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonToTask(Map json) → TTVideoEngineDownloadTask