TTVideoEngineSRConfig class

Constructors

TTVideoEngineSRConfig({bool autoStart = true, bool asynInit = true, bool enableSoftDecodeSR = false, int scaleType = -1, int algorithm = -1})

Properties

algorithm → int
final
asynInit → bool
final
autoStart → bool
final
enableSoftDecodeSR → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleType → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited