TTMasterRendition class

Constructors

TTMasterRendition({String? type, String? uri, String? assocLanguage, bool? autoSelect, bool? forced, String? groupId, int? infoId, bool? isDefault, String? language, String? name, int? trackType, int? variantIndex, String? inStreamId, String? characteristics, String? channels})
TTMasterRendition.fromJson(Map<String, dynamic> json)
factory

Properties

assocLanguage ↔ String?
getter/setter pair
autoSelect ↔ bool?
getter/setter pair
channels ↔ String?
getter/setter pair
characteristics ↔ String?
getter/setter pair
forced ↔ bool?
getter/setter pair
groupId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infoId ↔ int?
getter/setter pair
inStreamId ↔ String?
getter/setter pair
isDefault ↔ bool?
getter/setter pair
language ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackType ↔ int?
getter/setter pair
type ↔ String?
getter/setter pair
uri ↔ String?
getter/setter pair
variantIndex ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited