TTMasterVariantStream class

Constructors

TTMasterVariantStream({String? audioGroupId, int? averageBandwidth, int? bandwidth, String? closedCaptionsGroupId, String? codecs, double? frameRate, String? hdcpLevel, int? programId, String? resolution, String? subtitleGroupId, String? videoGroupId, String? uri})
TTMasterVariantStream.fromJson(Map<String, dynamic> json)
factory

Properties

audioGroupId ↔ String?
getter/setter pair
averageBandwidth ↔ int?
getter/setter pair
bandwidth ↔ int?
getter/setter pair
closedCaptionsGroupId ↔ String?
getter/setter pair
codecs ↔ String?
getter/setter pair
frameRate ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hdcpLevel ↔ String?
getter/setter pair
programId ↔ int?
getter/setter pair
resolution ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleGroupId ↔ String?
getter/setter pair
uri ↔ String?
getter/setter pair
videoGroupId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited