TTVideoEngineMediaSource class abstract

Implementers

Constructors

TTVideoEngineMediaSource()

Properties

codecStrategy ↔ TTVideoEngineCodecStrategy
getter/setter pair
enableFallbackRefresh ↔ bool
getter/setter pair
getUniqueId → String?
no setter
getVid → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → TTVideoEngineSourceType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String jsonStr) → TTVideoEngineMediaSource