TTVideoEngineVideoModelSource class

Inheritance

Constructors

TTVideoEngineVideoModelSource({String? vid, double? duration, TTVideoEngineResolutionType? resolution, List<PlayInfoListItem>? playInfoList, String? jsonModel})
TTVideoEngineVideoModelSource.fromJson(Map<String, dynamic> json)
factory
TTVideoEngineVideoModelSource.init({required String vid, TTVideoEngineResolutionType? resolution, List<PlayInfoListItem>? playInfoList, double? duration, String? jsonModel})
Create TTVideoEngineVideoModelSource instance, data is passed to native layer in JSON format
factory

Properties

codecStrategy ↔ TTVideoEngineCodecStrategy
getter/setter pairinherited
duration → double?
Video duration in seconds
final
enableFallbackRefresh ↔ bool
getter/setter pairinherited
getUniqueId → String?
no setteroverride
getVid → String?
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
jsonModel → String?
Video json model, usually from GetPlayInfo API, use the Result of GetPlayInfo API response
final
playInfoList → List<PlayInfoListItem>?
Video play info list
final
resolution → TTVideoEngineResolutionType?
Video resolution
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → TTVideoEngineSourceType
no setteroverride
vid → String?
Video vid
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonToMediaSource(Map<String, dynamic> json) → TTVideoEngineMediaSource