TTVideoEngineLoadProgress class

Constructors

TTVideoEngineLoadProgress({String? videoId, TTVideoEngineDataLoaderTaskType? taskType, List<TTVideoEngineLoadCacheInfo>? cacheInfos, TTVideoEngineCacheState? cacheState, bool? preloadComplete, bool? cacheEnd, int? totalCacheSize, int? totalMediaSize})
TTVideoEngineLoadProgress.fromJson(Map json)
factory

Properties

cacheEnd ↔ bool?
getter/setter pair
cacheInfos ↔ List<TTVideoEngineLoadCacheInfo>?
getter/setter pair
cacheState ↔ TTVideoEngineCacheState?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
preloadComplete ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskType ↔ TTVideoEngineDataLoaderTaskType?
getter/setter pair
totalCacheSize ↔ int?
getter/setter pair
totalMediaSize ↔ int?
getter/setter pair
videoId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited