TTVideoEnginePreloaderURLItem class

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
getter/setter pair
onPreloadCancel ↔ OnPreloadCancel?
getter/setter pair
onPreloadEnd ↔ OnPreloadEnd?
getter/setter pair
preloadSize ↔ int
getter/setter pair
priorityLevel ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urls ↔ List<String>?
getter/setter pair
videoId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(dynamic error) → void
onEvent(dynamic event) → void
registEvent() → void
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited