TTVideoEngineEncodeType enum

Inheritance
Available extensions

Values

h264 → const TTVideoEngineEncodeType
const TTVideoEngineEncodeType(0)
h265 → const TTVideoEngineEncodeType
const TTVideoEngineEncodeType(3)
byteVC2 → const TTVideoEngineEncodeType
const TTVideoEngineEncodeType(4)

Properties

hashCode → int
The hash code for this object.
no setterinherited
idx → int
final
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TTVideoEngineEncodeType>
A constant List of the values in this enum, in order of their declaration.