TTVideoEngineVidSource class

Inheritance

Constructors

TTVideoEngineVidSource({String? vid, String? playAuthToken, TTVideoEngineResolutionType? resolution, String? drmLicenseAuthToken, Uint8List? certData, TTVideoEngineEncodeType? encodeType = TTVideoEngineEncodeType.h264})
TTVideoEngineVidSource.fromJson(Map<String, dynamic> json)
factory
TTVideoEngineVidSource.init({required String? vid, required String? playAuthToken, TTVideoEngineResolutionType? resolution, String? drmLicenseAuthToken, Uint8List? certData, TTVideoEngineEncodeType? encodeType})
factory

Properties

certData ↔ Uint8List?
getter/setter pair
codecStrategy ↔ TTVideoEngineCodecStrategy
getter/setter pairinherited
drmLicenseAuthToken ↔ String?
getter/setter pair
enableFallbackRefresh ↔ bool
getter/setter pairinherited
encodeType ↔ TTVideoEngineEncodeType?
getter/setter pair
getUniqueId → String?
no setteroverride
getVid → String?
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isDash ↔ bool?
getter/setter pair
isHLS ↔ bool?
getter/setter pair
playAuthToken ↔ String?
play auth token
getter/setter pair
resolution ↔ TTVideoEngineResolutionType?
resolution type
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → TTVideoEngineSourceType
no setteroverride
vid ↔ String?
video id
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonToMediaSource(Map<String, dynamic> json) → TTVideoEngineMediaSource